CompressionBackend

Enum CompressionBackend 

pub enum CompressionBackend {
    Ffi,
    Pure,
}
Selects which backend to use when both FFI and pure-Rust implementations are compiled in for the same codec (szip or zstd).

When only one feature is enabled the backend field is ignored — the available implementation is always used.

The default is resolved once from the TENSOGRAM_COMPRESSION_BACKEND environment variable (values: ffi or pure). On wasm32 the default is always Pure.

Variants



Ffi

Use the C FFI implementation (libaec for szip, libzstd for zstd). Falls back to pure-Rust if the FFI feature is not compiled in.



Pure

Use the pure-Rust implementation (tensogram-szip, ruzstd). Falls back to FFI if the pure feature is not compiled in.