pub fn compute_hash(data: &[u8], algorithm: HashAlgorithm) -> StringExpand description
Compute a hash of the given data, returning the hex-encoded digest.
pub fn compute_hash(data: &[u8], algorithm: HashAlgorithm) -> StringCompute a hash of the given data, returning the hex-encoded digest.