verify_hash

Function verify_hash 

pub fn verify_hash(
    data: &[u8],
    descriptor: &HashDescriptor,
) -> Result<(), TensogramError>
Verify a hash descriptor against data.

If the hash algorithm is not recognized, a warning is logged and verification is skipped (returns Ok). This ensures forward compatibility when new hash algorithms are added.