pub fn decode_data_object_frame(
buf: &[u8],
) -> Result<(DataObjectDescriptor, &[u8], usize), TensogramError>Expand description
Decode a data object frame, returning the descriptor and payload slice.
buf must start at the frame header.
pub fn decode_data_object_frame(
buf: &[u8],
) -> Result<(DataObjectDescriptor, &[u8], usize), TensogramError>Decode a data object frame, returning the descriptor and payload slice.
buf must start at the frame header.