pub fn decode_message(buf: &[u8]) -> Result<DecodedMessage<'_>>Expand description
Decode a complete message from a buffer.
Validates that frames appear in the expected order: header frames first, then data objects, then footer frames.
pub fn decode_message(buf: &[u8]) -> Result<DecodedMessage<'_>>Decode a complete message from a buffer.
Validates that frames appear in the expected order: header frames first, then data objects, then footer frames.