pub fn decode_metadata_only(
buf: &[u8],
) -> Result<GlobalMetadata, TensogramError>Expand description
Decode only global metadata from a message, skipping data frames.
pub fn decode_metadata_only(
buf: &[u8],
) -> Result<GlobalMetadata, TensogramError>Decode only global metadata from a message, skipping data frames.