pub struct IndexFrame {
pub object_count: u64,
pub offsets: Vec<u64>,
pub lengths: Vec<u64>,
}Expand description
Index frame payload — maps object ordinals to byte offsets.
Fields
object_count: u64offsets: Vec<u64>Byte offset of each data object frame from message start.
lengths: Vec<u64>Total byte length of each data object frame, excluding alignment padding.