pub fn encode_data_object_frame(
descriptor: &DataObjectDescriptor,
payload: &[u8],
cbor_before: bool,
) -> Result<Vec<u8>, TensogramError>Expand description
Encode a data object frame with CBOR descriptor after payload (default).
Layout: FrameHeader(16) | payload_bytes | cbor_bytes | cbor_offset(8) + ENDF(4)
The cbor_offset in the footer is the byte offset from frame start to the start of the CBOR descriptor.