pub struct MessageFlags(/* private fields */);Expand description
Flags in the message preamble indicating which optional frames are present.
Implementations
Sourceimpl MessageFlags
impl MessageFlags
pub const HEADER_METADATA: u16
pub const FOOTER_METADATA: u16
pub const HEADER_INDEX: u16
pub const FOOTER_INDEX: u16
pub const HEADER_HASHES: u16
pub const FOOTER_HASHES: u16
Sourcepub const PRECEDER_METADATA: u16
pub const PRECEDER_METADATA: u16
At least one PrecederMetadata frame is present in the data objects section.
pub fn new(bits: u16) -> MessageFlags
pub fn bits(self) -> u16
pub fn has(self, flag: u16) -> bool
pub fn set(&mut self, flag: u16)
Sourcepub fn has_metadata(self) -> bool
pub fn has_metadata(self) -> bool
Returns true if at least one metadata frame (header or footer) is present.